export declare class XMLElement {
    private element;
    private attributes;
    private content;
    private children;
    constructor(element: string, attributes?: Attribute[], content?: string);
    /**
     * Sets the text content of the XML element
     * @param content The text content of the XML element
     */
    setText(content: string): this;
    /**
     *
     * @returns The text content of the XML element
     */
    getText(): string;
    /**
     * Removes the text content of the element
     */
    removeText(): void;
    /**
     * Adds a XML child to the element
     * @param XMLElement child
     */
    addChild(XMLElement: XMLElement): this;
    /**
     * Removes child from the XML element
     * @param XMLElement Element to remove
     */
    removeChild(XMLElement: XMLElement): void;
    /**
     * Removes all children elements
     */
    removeAllChildren(): void;
    /**
     * Add multiple children to the element
     * @param XMLElements
     */
    addChildren(XMLElements: XMLElement[]): this;
    /**
     * Add attribute to the XML element
     * @param attribute
     */
    addAttribute(attribute: Attribute): this;
    /**
     * Removes attribute from the element
     * @param attribute Attribute to remove
     */
    removeAttribute(attribute: Attribute): void;
    /**
     * Removes all attributes from the element
     */
    removeAllAttributes(): void;
    /**
     *
     * @returns All the attributes of the element
     */
    getAttributes(): Attribute[];
    /**
     *
     * @returns All children elements
     */
    getChildren(): XMLElement[];
    /**
     * Add an array of atrributes to the element
     * @param attributes
     */
    addAttributes(attributes: Attribute[]): this;
    /**
     *
     * @returns The XML element in string format
     */
    toXML(): string;
}
export type Attribute = {
    attribute: string;
    value?: string;
};
