"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.XMLElement = void 0;
var XMLElement = /** @class */ (function () {
    function XMLElement(element, attributes, content) {
        this.attributes = [];
        this.children = [];
        this.element = element;
        if (attributes && attributes.length)
            this.attributes = attributes;
        if (content) {
            this.content = content;
        }
    }
    /**
     * Sets the text content of the XML element
     * @param content The text content of the XML element
     */
    XMLElement.prototype.setText = function (content) {
        this.content = content;
        return this;
    };
    /**
     *
     * @returns The text content of the XML element
     */
    XMLElement.prototype.getText = function () {
        return this.content;
    };
    /**
     * Removes the text content of the element
     */
    XMLElement.prototype.removeText = function () {
        this.content = null;
    };
    /**
     * Adds a XML child to the element
     * @param XMLElement child
     */
    XMLElement.prototype.addChild = function (XMLElement) {
        this.children.push(XMLElement);
        return this;
    };
    /**
     * Removes child from the XML element
     * @param XMLElement Element to remove
     */
    XMLElement.prototype.removeChild = function (XMLElement) {
        var _a;
        (_a = this.children) === null || _a === void 0 ? void 0 : _a.filter(function (child) { return child != XMLElement; });
    };
    /**
     * Removes all children elements
     */
    XMLElement.prototype.removeAllChildren = function () {
        this.children = [];
    };
    /**
     * Add multiple children to the element
     * @param XMLElements
     */
    XMLElement.prototype.addChildren = function (XMLElements) {
        var _a;
        (_a = this.children).push.apply(_a, XMLElements);
        return this;
    };
    /**
     * Add attribute to the XML element
     * @param attribute
     */
    XMLElement.prototype.addAttribute = function (attribute) {
        this.attributes.push(attribute);
        return this;
    };
    /**
     * Removes attribute from the element
     * @param attribute Attribute to remove
     */
    XMLElement.prototype.removeAttribute = function (attribute) {
        this.attributes.filter(function (attr) { return attr != attribute; });
    };
    /**
     * Removes all attributes from the element
     */
    XMLElement.prototype.removeAllAttributes = function () {
        this.attributes = [];
    };
    /**
     *
     * @returns All the attributes of the element
     */
    XMLElement.prototype.getAttributes = function () {
        return this.attributes;
    };
    /**
     *
     * @returns All children elements
     */
    XMLElement.prototype.getChildren = function () {
        return this.children;
    };
    /**
     * Add an array of atrributes to the element
     * @param attributes
     */
    XMLElement.prototype.addAttributes = function (attributes) {
        var _a;
        (_a = this.attributes).push.apply(_a, attributes);
        return this;
    };
    /**
     *
     * @returns The XML element in string format
     */
    XMLElement.prototype.toXML = function () {
        var _this = this;
        var _a;
        var attributes = "";
        var isSingleTag = !this.content && !this.children.length;
        if (this.attributes.length) {
            attributes = this.attributes.reduce(function (acc, attr, index) {
                return acc +
                    "".concat(attr.attribute).concat(attr.value ? '="' + attr.value + '"' : "") +
                    (index == _this.attributes.length - 1 ? "" : " ");
            }, " ");
        }
        var children = "";
        if (this.children) {
            children = this.children.reduce(function (acc, child) { return acc + child.toXML(); }, "");
        }
        var startTag = "<".concat(this.element).concat(attributes).concat(isSingleTag ? "/" : "", ">");
        var endTag = "</".concat(this.element, ">");
        return isSingleTag
            ? startTag
            : startTag + ((_a = this.content) !== null && _a !== void 0 ? _a : "") + children + endTag;
    };
    return XMLElement;
}());
exports.XMLElement = XMLElement;
